betbetter.core

Tiny client for the free Bet Better sports model API (https://betbetter.world/api/). No API key. Uses java.net.http, no dependencies.

Tiny client for the free Bet Better sports model API (https://betbetter.world/api/).
No API key. Uses java.net.http, no dependencies.
raw docstring

base-urlclj


best-betsclj

(best-bets sport)

picksclj

(picks sport)

Model picks for a sport, e.g. "nfl" or "nba"; returns the raw JSON string.

Model picks for a sport, e.g. "nfl" or "nba"; returns the raw JSON string.
raw docstring

predicted-scoresclj

(predicted-scores sport)

prop-betsclj

(prop-bets sport)

scorecardclj

(scorecard)

cljdoc builds & hosts documentation for Clojure/Script libraries