Tiny client for the free Bet Better sports model API (https://betbetter.world/api/). No API key. Uses java.net.http, no dependencies.
Tiny client for the free Bet Better sports model API (https://betbetter.world/api/). No API key. Uses java.net.http, no dependencies.
(best-bets sport)(picks sport)Model picks for a sport, e.g. "nfl" or "nba"; returns the raw JSON string.
Model picks for a sport, e.g. "nfl" or "nba"; returns the raw JSON string.
(predicted-scores sport)(prop-bets sport)(scorecard)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |